==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grup important :</b> és molt aconssellable seleccionar una contrasenya a aquest grup. ',
	'avis_doublon_mot_cle' => 'Ja hi ha una paraula amb aquest títol. Esteu segurs de voler crear la mateixa?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'els administradors del lloc',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'els redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'els visitants del lloc públic quan posen un missatge a un fòrum.',

	// C
	'creer_et_associer_un_mot' => 'Créér et associer un mot-clé', # MODIF

	// I
	'icone_creation_groupe_mots' => 'Crear un nou grup de paraules',
	'icone_creation_mots_cles' => 'Crear una nova paraula clau',
	'icone_modif_groupe_mots' => 'Modificar aquest grup de paraules',
	'icone_modifier_mot' => 'Modificar aquesta paraula clau',
	'icone_mots_cles' => 'Paraules clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aquest grup',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots', # NEW
	'icone_voir_tous_mots_cles' => 'Mostrar totes les paraules clau',
	'info_1_groupe_mots' => '1 groupe de mots', # NEW
	'info_articles_lies_mot' => 'Articles lligats a aquesta paraula clau',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots', # NEW
	'info_aucun_mot_cle' => 'Cap paraula clau',
	'info_changer_nom_groupe' => 'Canviar el nom d\'aquest grup:',
	'info_creation_mots_cles' => 'Crear i configurar aquí les paraules clau del lloc',
	'info_dans_groupe' => 'Dins el grup:',
	'info_delet_mots_cles' => 'Heu sol·licitat la supressió de la
 paraula clau <b>@titre_mot@</b> (@type_mot@). Donat que la paraula-clau està lligada a
<b>@texte_lie@</b> heu de confirmar aquesta decisió:', # MODIF
	'info_groupe_important' => 'Grup important',
	'info_modifier_mot' => 'Modificar la paraula clau:',
	'info_mots_cles' => 'Les paraules clau',
	'info_mots_cles_association' => 'Les paraules clau d\'aquest grup poden ser associades:',
	'info_nb_groupe_mots' => '@nb@ groupes de mots', # NEW
	'info_oui_suppression_mot_cle' => 'vull suprimir definitivament aquesta paraula clau.',
	'info_question_mots_cles' => 'Voleu utilitzar les paraules clau en la vostra web ?',
	'info_qui_attribue_mot_cle' => 'Les paraules clau d\'aquest grup poden ser assignades per:',
	'info_remplacer_mot' => 'Substituir "@titre@"',
	'info_retirer_mot' => 'suprimir aquesta paraula',
	'info_retirer_mots' => 'suprimir totes les paraules',
	'info_rubriques_liees_mot' => 'Seccions associades a aquesta paraula clau',
	'info_selection_un_seul_mot_cle' => 'Podeu seleccionar <b>només una paraula clau</b> cada vegada en aquest grup.', # MODIF
	'info_supprimer_mot' => 'suprimir aquesta paraula',
	'info_titre_mot_cle' => 'Nom o títol de la paraula clau',
	'info_un_mot' => 'Una sola paraula a la vegada',
	'item_ajout_mots_cles' => 'Autoritzar l\'afegit de paraules clau als fòrums',
	'item_non_ajout_mots_cles' => 'Prohibir la utilització de les paraules clau en els fòrums',
	'item_non_utiliser_config_groupe_mots_cles' => 'No utilitzar la configuració avançada dels grup de paraules clau',
	'item_non_utiliser_mots_cles' => 'No utilitzar les paraules clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilitzar la configuració avançada dels grups de paraules clau',
	'item_utiliser_mots_cles' => 'Utilitzar les paraules clau',

	// L
	'lien_ajouter_mot' => 'Afegir aquesta paraula clau',
	'logo_groupe' => 'LOGOTIP D\'AQUEST GRUP',
	'logo_mot_cle' => 'LOGOTIP DE LA PARAULA CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Voleu activar la configuració avançada de les paraules clau,
  indicant per exemple que es pot seleccionar un mot únic
  per grup, quin grup és important...?', # MODIF
	'texte_mots_cles' => 'Les paraules clau permeten crear enllaços tematics entre els articles
independement del seu emplaçament a les seccions.Es pot així
enriquir la navegació del vostre lloc, inclús utilitzar aquestes propietats
 per a personalitzar la presentació dels articles dintre dels esquelets.',
	'texte_mots_cles_dans_forum' => 'Voleu permetre l\'ús de paraules clau, escollides pels visitants, als fòrums del lloc públic? (Atenció: aquesta opció és relativament complexa d\'utilitzar correctament) ',
	'texte_nouveau_mot' => 'Nova paraula',
	'titre_config_groupe_mots_cles' => 'Configuració dels grups de paraules clau',
	'titre_gauche_mots_edit' => 'MOT NÚMERO:',
	'titre_groupe_mots' => 'Groupe de mots-clés', # NEW
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :', # NEW
	'titre_groupes_mots' => 'Groupes de mots-clés', # NEW
	'titre_mots_cles_dans_forum' => 'Paraules clau dins dels fòrums del lloc públic',
	'titre_mots_tous' => 'Les paraules clau',
	'titre_nouveau_groupe' => 'Grup nou',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :', # NEW
	'titre_page_mots_tous' => 'Paraules clau'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/mots/lang/mots_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grup important :</b> és molt aconssellable seleccionar una contrasenya a aquest grup. ',
	'avis_doublon_mot_cle' => 'Ja hi ha una paraula amb aquest títol. Esteu segurs de voler crear la mateixa?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'els administradors del lloc',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'els redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'els visitants del lloc públic quan posen un missatge a un fòrum.',

	// C
	'creer_et_associer_un_mot' => 'Créér et associer un mot-clé', # MODIF

	// I
	'icone_creation_groupe_mots' => 'Crear un nou grup de paraules',
	'icone_creation_mots_cles' => 'Crear una nova paraula clau',
	'icone_modif_groupe_mots' => 'Modificar aquest grup de paraules',
	'icone_modifier_mot' => 'Modificar aquesta paraula clau',
	'icone_mots_cles' => 'Paraules clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aquest grup',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots', # NEW
	'icone_voir_tous_mots_cles' => 'Mostrar totes les paraules clau',
	'info_1_groupe_mots' => '1 groupe de mots', # NEW
	'info_articles_lies_mot' => 'Articles lligats a aquesta paraula clau',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots', # NEW
	'info_aucun_mot_cle' => 'Cap paraula clau',
	'info_changer_nom_groupe' => 'Canviar el nom d\'aquest grup:',
	'info_creation_mots_cles' => 'Crear i configurar aquí les paraules clau del lloc',
	'info_dans_groupe' => 'Dins el grup:',
	'info_delet_mots_cles' => 'Heu sol·licitat la supressió de la
 paraula clau <b>@titre_mot@</b> (@type_mot@). Donat que la paraula-clau està lligada a
<b>@texte_lie@</b> heu de confirmar aquesta decisió:', # MODIF
	'info_groupe_important' => 'Grup important',
	'info_modifier_mot' => 'Modificar la paraula clau:',
	'info_mots_cles' => 'Les paraules clau',
	'info_mots_cles_association' => 'Les paraules clau d\'aquest grup poden ser associades:',
	'info_nb_groupe_mots' => '@nb@ groupes de mots', # NEW
	'info_oui_suppression_mot_cle' => 'vull suprimir definitivament aquesta paraula clau.',
	'info_question_mots_cles' => 'Voleu utilitzar les paraules clau en la vostra web ?',
	'info_qui_attribue_mot_cle' => 'Les paraules clau d\'aquest grup poden ser assignades per:',
	'info_remplacer_mot' => 'Substituir "@titre@"',
	'info_retirer_mot' => 'suprimir aquesta paraula',
	'info_retirer_mots' => 'suprimir totes les paraules',
	'info_rubriques_liees_mot' => 'Seccions associades a aquesta paraula clau',
	'info_selection_un_seul_mot_cle' => 'Podeu seleccionar <b>només una paraula clau</b> cada vegada en aquest grup.', # MODIF
	'info_supprimer_mot' => 'suprimir aquesta paraula',
	'info_titre_mot_cle' => 'Nom o títol de la paraula clau',
	'info_un_mot' => 'Una sola paraula a la vegada',
	'item_ajout_mots_cles' => 'Autoritzar l\'afegit de paraules clau als fòrums',
	'item_non_ajout_mots_cles' => 'Prohibir la utilització de les paraules clau en els fòrums',
	'item_non_utiliser_config_groupe_mots_cles' => 'No utilitzar la configuració avançada dels grup de paraules clau',
	'item_non_utiliser_mots_cles' => 'No utilitzar les paraules clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilitzar la configuració avançada dels grups de paraules clau',
	'item_utiliser_mots_cles' => 'Utilitzar les paraules clau',

	// L
	'lien_ajouter_mot' => 'Afegir aquesta paraula clau',
	'logo_groupe' => 'LOGOTIP D\'AQUEST GRUP',
	'logo_mot_cle' => 'LOGOTIP DE LA PARAULA CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Voleu activar la configuració avançada de les paraules clau,
  indicant per exemple que es pot seleccionar un mot únic
  per grup, quin grup és important...?', # MODIF
	'texte_mots_cles' => 'Les paraules clau permeten crear enllaços tematics entre els articles
independement del seu emplaçament a les seccions.Es pot així
enriquir la navegació del vostre lloc, inclús utilitzar aquestes propietats
 per a personalitzar la presentació dels articles dintre dels esquelets.',
	'texte_mots_cles_dans_forum' => 'Voleu permetre l\'ús de paraules clau, escollides pels visitants, als fòrums del lloc públic? (Atenció: aquesta opció és relativament complexa d\'utilitzar correctament) ',
	'texte_nouveau_mot' => 'Nova paraula',
	'titre_config_groupe_mots_cles' => 'Configuració dels grups de paraules clau',
	'titre_gauche_mots_edit' => 'MOT NÚMERO:',
	'titre_groupe_mots' => 'Groupe de mots-clés', # NEW
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :', # NEW
	'titre_groupes_mots' => 'Groupes de mots-clés', # NEW
	'titre_mots_cles_dans_forum' => 'Paraules clau dins dels fòrums del lloc públic',
	'titre_mots_tous' => 'Les paraules clau',
	'titre_nouveau_groupe' => 'Grup nou',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :', # NEW
	'titre_page_mots_tous' => 'Paraules clau'
);

?>
